@@ -11,6 +11,8 @@ from airflow.models.baseoperator import BaseOperator
 from airflow.models.dag import DAG
 from airflow.models.dagbag import DagBag
 from airflow.settings import LOG_FORMAT
+from dagster_airflow.patch_airflow_example_dag import patch_airflow_example_dag
+
 from dagster import (
     DagsterInvariantViolationError,
     DependencyDefinition,
@@ -26,7 +28,6 @@ from dagster import (
 )
 from dagster.core.definitions.utils import VALID_NAME_REGEX, validate_tags
 from dagster.core.instance import AIRFLOW_EXECUTION_DATE_STR, IS_AIRFLOW_INGEST_PIPELINE_STR
-from dagster_airflow.patch_airflow_example_dag import patch_airflow_example_dag
 
 
 class DagsterAirflowError(Exception):
@@ -213,7 +214,7 @@ def make_dagster_repo_from_airflow_dags_path(
             safe_mode=safe_mode,
             store_serialized_dags=store_serialized_dags,
         )
-    except Exception:  # pylint: disable=broad-except
+    except Exception:
         raise DagsterAirflowError("Error initializing airflow.models.dagbag object with arguments")
 
     return make_dagster_repo_from_airflow_dag_bag(dag_bag, repo_name, use_airflow_template_context)
@@ -378,9 +379,9 @@ def _traverse_airflow_dag(
 
 @contextmanager
 def replace_airflow_logger_handlers():
+    prev_airflow_handlers = logging.getLogger("airflow.task").handlers
     try:
         # Redirect airflow handlers to stdout / compute logs
-        prev_airflow_handlers = logging.getLogger("airflow.task").handlers
         handler = logging.StreamHandler(sys.stdout)
         handler.setFormatter(logging.Formatter(LOG_FORMAT))
         root = logging.getLogger("airflow.task")
@@ -406,8 +407,9 @@ def make_dagster_solid_from_airflow_task(task, use_airflow_template_context, uni
     def _solid(context):  # pylint: disable=unused-argument
         if AIRFLOW_EXECUTION_DATE_STR not in context.pipeline_run.tags:
             raise DagsterInvariantViolationError(
-                'Could not find "{AIRFLOW_EXECUTION_DATE_STR}" in pipeline tags "{tags}". Please '
-                'add "{AIRFLOW_EXECUTION_DATE_STR}" to pipeline tags before executing'.format(
+                'Could not find "{AIRFLOW_EXECUTION_DATE_STR}" in {target} tags "{tags}". Please '
+                'add "{AIRFLOW_EXECUTION_DATE_STR}" to {target} tags before executing'.format(
+                    target="job" if context.pipeline_def.is_graph_job_op_target else "pipeline",
                     AIRFLOW_EXECUTION_DATE_STR=AIRFLOW_EXECUTION_DATE_STR,
                     tags=context.pipeline_run.tags,
                 )
